#!/usr/bin/python
# -*- coding: utf-8 -*-

import json

class OrderAPI(object):

    @classmethod
    def load_order(cls, order):
        structure = order.get("structure", None)
        if structure: order["details"] = json.loads(structure)
        else: order["details"] = dict()
        return order

    def list_orders(self, *args, **kwargs):
        url = self.base_url + "orders"
        contents = self.get(url, **kwargs)
        return contents

    def create_order(self, order):
        url = self.base_url + "orders"
        contents = self.post(url, data_j = order)
        return contents

    def get_order(self, number):
        url = self.base_url + "orders/%d" % number
        contents = self.get(url)
        return contents

    def price_order(self, number, currency = None):
        url = self.base_url + "orders/%d/price" % number
        contents = self.get(url, currency = currency)
        return contents

    def report_pdf(self, number):
        url = self.base_url + "orders/%d/report.pdf" % number
        contents = self.get(url, number)
        return contents

    def import_order(
        self,
        ff_order_id,
        contents,
        currency = None,
        country = None,
        meta = None,
        safe = True,
        notify = False,
        pending = False,
        *args,
        **kwargs
    ):
        url = self.base_url + "orders/import"
        contents = self.post(
            url,
            ff_order_id = ff_order_id,
            contents = contents,
            currency = currency,
            country = country,
            meta = meta,
            safe = safe,
            notify = notify,
            pending = pending,
            **kwargs
        )
        return contents

    def create_farfetch_order(
        self,
        ff_order_id,
        contents,
        currency = None,
        country = None,
        meta = None,
        safe = True,
        notify = False,
        *args,
        **kwargs
    ):
        url = self.base_url + "orders/farfetch"
        contents = self.post(
            url,
            ff_order_id = ff_order_id,
            contents = contents,
            currency = currency,
            country = country,
            meta = meta,
            safe = safe,
            notify = notify,
            **kwargs
        )
        return contents



#!/usr/bin/python
# -*- coding: utf-8 -*-

class ConfigAPI(object):

    def get_config(self):
        url = self.base_url + "config"
        contents = self.get(url)
        return contents

    def info_config(self, *args, **kwargs):
        url = self.base_url + "config/info"
        contents = self.get(url, auth = False, **kwargs)
        return contents

    def sku_config(self, *args, **kwargs):
        url = self.base_url + "config/sku"
        contents = self.get(url, auth = False, **kwargs)
        return contents

    def price_config(self, *args, **kwargs):
        url = self.base_url + "config/price"
        contents = self.get(url, auth = False, **kwargs)
        return contents

    def availability_config(self, *args, **kwargs):
        url = self.base_url + "config/availability"
        contents = self.get(url, auth = False, **kwargs)
        return contents

    def resolve_config(self, product_id):
        url = self.base_url + "config/resolve/%s" % product_id
        contents = self.get(url, auth = False)
        return contents

    def defaults_model_config(self, model):
        url = self.base_url + "config/defaults/%s" % model
        contents = self.get(url, auth = False)
        return contents



#!/usr/bin/python
# -*- coding: utf-8 -*-

class LocaleAPI(object):

    def locale_m_locale(self, values, locale = "en-us"):
        url = self.base_url + "locale"
        contents = self.post(
            url,
            values = values,
            locale = locale
        )
        return contents

    def locale_s_locale(self, value, locale = "en-us"):
        url = self.base_url + "locale" + "/" + value
        contents = self.post(
            url,
            locale = locale
        )
        return contents



#!/usr/bin/python
# -*- coding: utf-8 -*-

import appier

from . import brand
from . import model
from . import order
from . import config
from . import size
from . import locale

RIPE_BASE_URL = "http://localhost/api/"
""" The default base URL to be used when no other
base URL value is provided to the constructor """

class API(
    appier.API,
    brand.BrandAPI,
    model.ModelAPI,
    order.OrderAPI,
    config.ConfigAPI,
    size.SizeAPI,
    locale.LocaleAPI
):

    def __init__(self, *args, **kwargs):
        appier.API.__init__(self, *args, **kwargs)
        self.base_url = appier.conf("RIPE_BASE_URL", RIPE_BASE_URL)
        self.username = appier.conf("RIPE_USERNAME", None)
        self.password = appier.conf("RIPE_PASSWORD", None)
        self.secret_key = appier.conf("RIPE_SECRET_KEY", None)
        self.admin = appier.conf("RIPE_ADMIN", True, cast = bool)
        self.base_url = kwargs.get("base_url", self.base_url)
        self.username = kwargs.get("username", self.username)
        self.password = kwargs.get("password", self.password)
        self.secret_key = kwargs.get("secret_key", self.secret_key)
        self.admin = kwargs.get("admin", self.admin)
        self.session_id = kwargs.get("session_id", None)
        self.token = kwargs.get("token", None)

    def build(
        self,
        method,
        url,
        data = None,
        data_j = None,
        data_m = None,
        headers = None,
        params = None,
        mime = None,
        kwargs = None
    ):
        auth = kwargs.pop("auth", True)
        if auth and self.secret_key: headers["X-Secret-Key"] = self.secret_key
        if auth and not self.secret_key: params["sid"] = self.get_session_id()

    def get_session_id(self):
        if self.session_id: return self.session_id
        return self.login()

    def auth_callback(self, params, headers):
        self.session_id = None
        session_id = self.get_session_id()
        params["sid"] = session_id

    def login(self, username = None, password = None, admin = None):
        username = username or self.username
        password = password or self.password
        admin = admin or self.admin
        url = self.base_url + ("signin_admin" if admin else "signin")
        contents = self.post(
            url,
            callback = False,
            auth = False,
            username = username,
            password = password
        )
        self.username = contents.get("username", None)
        self.session_id = contents.get("session_id", None)
        self.tokens = contents.get("tokens", None)
        self.trigger("auth", contents)
        return self.session_id

    def login_pid(self, token = None):
        token = token or self.token
        url = self.base_url + "signin_pid"
        contents = self.post(
            url,
            callback = False,
            auth = False,
            token = token
        )
        self.username = contents.get("username", None)
        self.session_id = contents.get("session_id", None)
        self.tokens = contents.get("tokens", None)
        self.trigger("auth", contents)
        return self.session_id

    def is_auth(self):
        if not self.username: return False
        if not self.password: return False
        return True



#!/usr/bin/python
# -*- coding: utf-8 -*-

class SizeAPI(object):

    def get_sizes(self):
        url = self.base_url + "sizes"
        contents = self.get(url, auth = False)
        return contents

    def size_to_native(self, scale, value, gender):
        url = self.base_url + "sizes/size_to_native"
        contents = self.get(
            url,
            auth = False,
            scale = scale,
            value = value,
            gender = gender
        )
        return contents

    def size_to_native_b(self, scales, values, genders):
        url = self.base_url + "sizes/size_to_native_b"
        contents = self.get(
            url,
            auth = False,
            scales = scales,
            values = values,
            genders = genders
        )
        return contents

    def native_to_size(self, scale, value, gender):
        url = self.base_url + "sizes/native_to_size"
        contents = self.get(
            url,
            auth = False,
            scale = scale,
            value = value,
            gender = gender
        )
        return contents

    def native_to_size_b(self, scales, values, genders):
        url = self.base_url + "sizes/native_to_size_b"
        contents = self.get(
            url,
            auth = False,
            scales = scales,
            values = values,
            genders = genders
        )
        return contents



#!/usr/bin/python
# -*- coding: utf-8 -*-

class BrandAPI(object):

    def logo_brand(self, brand, format = "png", size = None):
        url = self.base_url + "brands/%s/models/%s/logo.%s" % (brand, format)
        contents = self.get(
            url,
            auth = False,
            size = size
        )
        return contents

    def config_brand(self, brand, model):
        url = self.base_url + "brands/%s/models/%s/config" % (brand, model)
        contents = self.get(url, auth = False)
        return contents

    def defaults_brand(self, brand, model):
        url = self.base_url + "brands/%s/models/%s/defaults" % (brand, model)
        contents = self.get(url, auth = False)
        return contents

    def combinations_brand(self, brand, model):
        url = self.base_url + "brands/%s/models/%s/combinations" % (brand, model)
        contents = self.get(url, auth = False)
        return contents

    def factory_brand(self, brand, model):
        url = self.base_url + "brands/%s/models/%s/factory" % (brand, model)
        contents = self.get(url, auth = False)
        return contents

    def validate_brand(self, brand, model, *args, **kwargs):
        url = self.base_url + "brands/%s/models/%s/validate" % (brand, model)
        contents = self.get(url, auth = False, **kwargs)
        return contents



#!/usr/bin/python
# -*- coding: utf-8 -*-

class ModelAPI(object):

    def config_model(self, model):
        url = self.base_url + "models/%s/config" % model
        contents = self.get(url, auth = False)
        return contents

    def defaults_model(self, model):
        url = self.base_url + "models/%s/defaults" % model
        contents = self.get(url, auth = False)
        return contents

    def combinations_model(self, model):
        url = self.base_url + "models/%s/combinations" % model
        contents = self.get(url, auth = False)
        return contents

    def factory_model(self, model):
        url = self.base_url + "models/%s/factory" % model
        contents = self.get(url, auth = False)
        return contents



#!/usr/bin/python
# -*- coding: utf-8 -*-

from . import base
from . import brand
from . import config
from . import model
from . import order
from . import size

from .base import API
from .brand import BrandAPI
from .config import ConfigAPI
from .model import ModelAPI
from .order import OrderAPI
from .size import SizeAPI
from .locale import LocaleAPI
